 *+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*
 *-       Overseas Transportation Infrastructure Layout, Formation Mode       -*
 *-                         and Outward Direct Investment                     -*
 *-               Authors: Huang Youxing, Qu Yanbing, Zhao Yanping            -*
 *-                            Edition:20220104                               -*
 *+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++* 
  
 *-
 use XXX/dataset.dta,clear
 *-
 tsset nocoun year

 *++++++++++++++++++++++++++++++++++
 *- Table 2:  Summary statistics
 *++++++++++++++++++++++++++++++++++
 global y2  "lnofdiflow"
 global x1  "lngdp lnpgdp gdpg exrate_change1 exp"
 global x2  "rat_exphigh rat_oilexp rat_oreexp"
 global o1  "lndist regdist"
 global o2  "lndiplo_age lnvisit lnpartner_5 lnaccq" 
 global c0 "if year>=2004"
 
 cap qui tabu year,gen(yeardum)
 cap drop yeardum1

 *-
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv($x1 $x2 $o1 $o2 yeardum*) twostep

 *- Panel A: Dependent variable
 tabstat  lnofdiflow if e(sample), s(N mean sd min p50 max) f(%12.3f) c(s)  
 
 *- Panel B: Kernel variables: Chinese transport infrastructure
 tabstat lnt_s_num lns_f_num_ofdi_p2 lns_f_num_proj2 lns_f_num_cont_p2   ///
         if e(sample), s(N mean sd min p50 max) f(%12.3f) c(s)   
               
 *- Panel C: Control variables
 tabstat  lngdp lnpgdp gdpg exrate_change1 exp                        ///
          rat_exphigh rat_oilexp rat_oreexp lndist regdist            ///
          lndiplo_age lnvisit lnpartner_5 lnaccq                      ///
          if e(sample), s(N mean sd min p50 max) f(%12.3f) c(s)  
 
 *+++++++++++++++++++++++++++++
 *- Table 3: Baseline results
 *+++++++++++++++++++++++++++++
 global y2  "lnofdiflow"
 
 global x1  "lngdp lnpgdp gdpg exrate_change1 exp"
 global x2  "rat_exphigh rat_oilexp rat_oreexp"

 global o1  "lndist regdist"
 global o2  "lndiplo_age lnvisit lnpartner_5 lnaccq" 
 
 global c0 "if year>=2004"
 
 cap qui tabu year,gen(yeardum)
 cap drop yeardum1
 
 *-
 tsset nocoun year
 
 *- A-1
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv() twostep
 est store A1
 *- A-2
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $x1 $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv($x1) twostep
 est store A2
 *- A-3
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $x1 $x2 $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv($x1 $x2) twostep
 est store A3
 *- A-4
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $x1 $x2 $o1 $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv($x1 $x2 $o1) twostep
 est store A4
 *- A-5 
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $x1 $x2 $o1 $o2 $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv($x1 $x2 $o1 $o2) twostep
 est store A5
 *- A-6
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store A6
 *- A-7
 qui xtabond2 $y2 L.lnofdiflow lnt_f_num $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_f_num) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store A7
 
 *-
 local s1 "L.lnofdiflow lnt_s_num lnt_f_num"
 local models "A1 A2 A3 A4 A5 A6 A7"
 local order "`s1'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g j hansen hansenp ar2 ar2p) ///
 sfmt(%10.0f %10.0f %10.0f %10.3f %10.3f %10.3f %10.3f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress  

 *+++++++++++++++++++++++++++++++
 *- Table 4: Robustness test 1
 *+++++++++++++++++++++++++++++++
 tsset nocoun year
 *+++++++++++++++++++++++++++++
 *- Panel A - Dynamic item Y 
 *+++++++++++++++++++++++++++++
 *- A-1: Lag 2 period
 qui xtabond2 $y2 L(1/2).lnofdiflow lnt_s_num $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L(1/2).lnofdiflow lnt_s_num) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store A1
 *- A-2: Lag 3 period
 qui xtabond2 $y2 L(1/3).lnofdiflow lnt_s_num $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L(1/3).lnofdiflow lnt_s_num) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store A2

 *-
 local s1 "L.lnofdiflow L2.lnofdiflow L3.lnofdiflow lnt_s_num"
 local models "A1 A2"
 local order "`s1'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress  

 *++++++++++++++++++++++++++++++++++++
 *- Panel B - Lagged key X variable 
 *++++++++++++++++++++++++++++++++++++
 *- B-1:Lag one period
 qui xtabond2 $y2 L.lnofdiflow L.lnt_s_num $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow L.lnt_s_num) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store B1
 *- B-2: Lag two period
 qui xtabond2 $y2 L.lnofdiflow L2.lnt_s_num $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow L2.lnt_s_num) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store B2
 
 local s1 "L.lnofdiflow L.lnt_s_num L2.lnt_s_num"
 local models "B1 B2"
 local order "`s1'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress  

 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 *- Panel C - Control variable: transport infrastructure in host countries
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 *-
 global tr1 "lnairgood" 
 global tr2 "lnrailgood" 
 global tr3 "lnportcontainer" 
 
 cap qui tabu year,gen(yeardum)
 cap drop yeardum1
 
 *-
 tsset nocoun year

 *- C-1:lnairgood
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $tr1 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv($tr1 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store C1
 *- C-2:lnrailgood
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $tr2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv($tr2 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store C2
 *- C-3:lnportcontainer
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $tr3 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv($tr3 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store C3

 *-
 local s1 "L.lnofdiflow lnt_s_num"
 local s2 "$tr1 $tr2 $tr3"
 local models "C1 C2 C3"
 local order "`s1' `s2'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress  

 *+++++++++++++++++++++++++++++++
 *- Table 5: Robustness test 2
 *+++++++++++++++++++++++++++++++

 *+++++++++++++++++++++++++++++
 *- Panel A - IV method
 *+++++++++++++++++++++++++++++
 *-
 tsset nocoun year

 cap qui tabu coun_code,gen(coundum)
 cap drop coundum1 
 
 *-
 global IV1  "pred_trans1"
 global IV2  "pred_trans2"
  
 *-
 qui xtabond2 $y2 L.lnofdiflow $IV1 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow $IV1) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store A1
 qui xtabond2 $y2 L.lnofdiflow $IV2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow $IV2) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store A2
   
 local s1 "L.lnofdiflow $IV1 $IV2"
 local models "A1 A2"
 local order "`s1'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 

 *+++++++++++++++++++++++++++++
 *- Panel B - Placebo test
 *+++++++++++++++++++++++++++++
 tsset nocoun year
 *+++++++++++++++++++++++++++++++
 *- B-1: Placebo:  pb_lnt_s_num
 *+++++++++++++++++++++++++++++++
 *-
 qui xtabond2 $y2 L.lnofdiflow pb_lnt_s_num $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow pb_lnt_s_num) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store B1
 
 local s1 "L.lnofdiflow pb_lnt_s_num"
 local models "B1"
 local order "`s1'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress  

 *+++++++++++++++++++++++++++++++
 *- B-2: Placebo: pb_lnofdiflow
 *+++++++++++++++++++++++++++++++
 global pby2  "pb_lnofdiflow"
 *-
 qui xtabond2 $pby2 L.pb_lnofdiflow lnt_s_num $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.pb_lnofdiflow lnt_s_num) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store B2
  
 local s1 "L.pb_lnofdiflow lnt_s_num"
 local models "B2"
 local order "`s1'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress  

 *+++++++++++++++++++++++++++++++++++++++++
 *- Table 6: Formation mode - INV AID PRO
 *+++++++++++++++++++++++++++++++++++++++++
 tsset nocoun year
 *- Panel A
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_ofdi_p2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_ofdi_p2) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_inv
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_proj2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_proj2) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_aid
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_cont_p2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_cont_p2) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_pro
 *- Panel B
 qui xtabond2 $y2 L.lnofdiflow lnf_num_ofdi_p2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnf_num_ofdi_p2) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store f_inv
 qui xtabond2 $y2 L.lnofdiflow lnf_num_proj2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnf_num_proj2) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store f_aid
 qui xtabond2 $y2 L.lnofdiflow lnf_num_cont_p2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnf_num_cont_p2) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store f_pro
 
 local s1 "L.lnofdiflow"
 local s2 "lns_f_num_ofdi_p2 lns_f_num_proj2 lns_f_num_cont_p2"
 local s3 "lnf_num_ofdi_p2 lnf_num_proj2 lnf_num_cont_p2"
 local models "s_inv s_aid s_pro f_inv f_aid f_pro"
 local order "`s1' `s2' `s3'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
  
 *+++++++++++++++++++++++++++++++++++++++++++++++++++
 *- Table 7: Spatial spillovers - Total INV AID PRO
 *+++++++++++++++++++++++++++++++++++++++++++++++++++
 *- Panel A
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num l_lnt_s_num $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv(l_lnt_s_num $x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_t
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_ofdi_p2 l_lns_f_num_ofdi_p2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_ofdi_p2) iv(l_lns_f_num_ofdi_p2 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_inv  
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_proj2 l_lns_f_num_proj2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_proj2) iv(l_lns_f_num_proj2 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_aid
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_cont_p2 l_lns_f_num_cont_p2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_cont_p2) iv(l_lns_f_num_cont_p2 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_pro
 *- Panel B
 qui xtabond2 $y2 L.lnofdiflow lnt_f_num l_lnt_f_num $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_f_num) iv(l_lnt_f_num $x1 $x2 $o1 $o2 yeardum*) twostep
 est store f_t
 qui xtabond2 $y2 L.lnofdiflow lnf_num_ofdi_p2 l_lnf_num_ofdi_p2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnf_num_ofdi_p2) iv(l_lnf_num_ofdi_p2 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store f_inv
 qui xtabond2 $y2 L.lnofdiflow lnf_num_proj2 l_lnf_num_proj2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnf_num_proj2) iv(l_lnf_num_proj2 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store f_aid
 qui xtabond2 $y2 L.lnofdiflow lnf_num_cont_p2 l_lnf_num_cont_p2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnf_num_cont_p2) iv(l_lnf_num_cont_p2 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store f_pro
 
 local s1 "L.lnofdiflow"
 local s2 "lnt_s_num lns_f_num_ofdi_p2 lns_f_num_proj2 lns_f_num_cont_p2 lnt_f_num lnf_num_ofdi_p2 lnf_num_proj2 lnf_num_cont_p2"
 local s3 "l_lnt_s_num l_lns_f_num_ofdi_p2 l_lns_f_num_proj2 l_lns_f_num_cont_p2 l_lnt_f_num l_lnf_num_ofdi_p2 l_lnf_num_proj2 l_lnf_num_cont_p2"
 local models "s_t s_inv s_aid s_pro f_t f_inv f_aid f_pro"
 local order "`s1' `s2' `s3'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
  
 *++++++++++++++++++++
 *-  Mechanism Test
 *++++++++++++++++++++
 *++++++++++++++++++++++++++++++++++++++++++++++++++++
 *-  Table 8: Panel A - Mechanism 1 (Cost reduction)
 *++++++++++++++++++++++++++++++++++++++++++++++++++++  
 global vari "lneasy"

 tsset nocoun year
 
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $vari $x1 $x2 $o1 $o2 yeardum*, ///
 gmm(L.lnofdiflow lnt_s_num $vari) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 
 gen ident = e(sample)
 
 tsset nocoun year
 
 global c0 "if ident == 1"
 
 *-
 xtreg $vari lnt_s_num yeardum* $c0,fe
 est store m1
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m2
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $vari $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num $vari) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m3
  
 local s1 "L.lnofdiflow"
 local s2 "lnt_s_num"
 local s3 "$vari"
 local models "m1 m2 m3"
 local order "`s1' `s2' `s3'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop ident
 
 *++++++++++++++++++++++++++++++++++++++++++++++++++
 *- Table 8: Panel B - Mechanism 2 (Agglomeration) 
 *++++++++++++++++++++++++++++++++++++++++++++++++++  
 global vari "popularge_r"
 tsset nocoun year
 
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $vari $x1 $x2 $o1 $o2 yeardum*, ///
 gmm(L.lnofdiflow lnt_s_num $vari) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 
 gen ident = e(sample)
 
 tsset nocoun year
 
 global c0 "if ident == 1"
 
 *-
 qui xtreg $vari lnt_s_num yeardum* $c0,fe
 est store m1
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m2
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $vari $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num $vari) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m3
  
 local s1 "L.lnofdiflow"
 local s2 "lnt_s_num"
 local s3 "$vari"
 local models "m1 m2 m3"
 local order "`s1' `s2' `s3'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop ident
 
 *+++++++++++++++++++++++++++++++++++++++++++++
 *- Table 9: Mechanism 3 (Political relations)
 *+++++++++++++++++++++++++++++++++++++++++++++
 global c0 ""
 *++++++++++++++++++++++++++++++++++++++
 *- Panel A - Short relations (country)
 *++++++++++++++++++++++++++++++++++++++
 gen cro1 = lnt_s_num         * lnvisit  
 gen cro2 = lns_f_num_ofdi_p2 * lnvisit 
 gen cro3 = lns_f_num_proj2   * lnvisit
 gen cro4 = lns_f_num_cont_p2 * lnvisit
 
 *-
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro1 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv(cro1 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_t

 qui xtabond2 $y2 L.lnofdiflow lns_f_num_ofdi_p2 cro2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_ofdi_p2) iv(cro2 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_inv 
 
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_proj2 cro3 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_proj2) iv(cro3 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_aid
  
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_cont_p2 cro4 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_cont_p2) iv(cro4 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_pro
 
 local s1 "L.lnofdiflow"
 local s2 "cro1 cro2 cro3 cro4"
 local s3 "lnt_s_num lns_f_num_ofdi_p2 lns_f_num_proj2 lns_f_num_cont_p2"
 local models "s_t s_inv s_aid s_pro"
 local order "`s1' `s2' `s3'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop cro*
 
 *++++++++++++++++++++++++++++++++++++++
 *- Panel B - long relations  (country)
 *++++++++++++++++++++++++++++++++++++++
 gen cro1 = lnt_s_num         * lnpartner_5   
 gen cro2 = lns_f_num_ofdi_p2 * lnpartner_5 
 gen cro3 = lns_f_num_proj2   * lnpartner_5
 gen cro4 = lns_f_num_cont_p2 * lnpartner_5
 *-
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro1 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv(cro1 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_t

 qui xtabond2 $y2 L.lnofdiflow lns_f_num_ofdi_p2 cro2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_ofdi_p2) iv(cro2 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_inv
 
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_proj2 cro3 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_proj2) iv(cro3 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_aid

 qui xtabond2 $y2 L.lnofdiflow lns_f_num_cont_p2 cro4 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_cont_p2) iv(cro4 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_pro

 local s1 "L.lnofdiflow"
 local s2 "cro1 cro2 cro3 cro4"
 local s3 "lnt_s_num lns_f_num_ofdi_p2 lns_f_num_proj2 lns_f_num_cont_p2"
 local models "s_t s_inv s_aid s_pro"
 local order "`s1' `s2' `s3'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop cro*
 
 *+++++++++++++++++++++++++++++++
 *- Panel C - Regional relations
 *+++++++++++++++++++++++++++++++
 gen cro1 = lnt_s_num         * lnaccq  
 gen cro2 = lns_f_num_ofdi_p2 * lnaccq   
 gen cro3 = lns_f_num_proj2   * lnaccq  
 gen cro4 = lns_f_num_cont_p2 * lnaccq  
 *-
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro1 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv(cro1 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_t

 qui xtabond2 $y2 L.lnofdiflow lns_f_num_ofdi_p2 cro2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_ofdi_p2) iv(cro2 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_inv 
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_proj2 cro3 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_proj2) iv(cro3 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_aid
  
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_cont_p2 cro4 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_cont_p2) iv(cro4 $x1 $x2 $o1 $o2 yeardum*) twostep
 est store s_pro
 
 local s1 "L.lnofdiflow"
 local s2 "cro1 cro2 cro3 cro4"
 local s3 "lnt_s_num lns_f_num_ofdi_p2 lns_f_num_proj2 lns_f_num_cont_p2"
 local models "s_t s_inv s_aid s_pro"
 local order "`s1' `s2' `s3'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop cro*

 *+++++++++++++++++++++++++++++++++++++++++
 *- Table 10: Mechanism 4: Security Threat
 *+++++++++++++++++++++++++++++++++++++++++
 
 *++++++++++++++++++++++++++++++++++++++++++
 *    Panel A: Armed conflicts
 *++++++++++++++++++++++++++++++++++++++++++  
 tsset nocoun year
 *- 
 global t1 "ln_att_ev_a"
 
 gen cro1 = lnt_s_num         * $t1
 gen cro2 = lns_f_num_ofdi_p2 * $t1
 gen cro3 = lns_f_num_proj2   * $t1
 gen cro4 = lns_f_num_cont_p2 * $t1
 *-
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro1 $x1 $x2 $o1 $o2 $t1 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv(cro1 $x1 $x2 $o1 $o2 $t1 yeardum*) twostep
 est store s_t

 qui xtabond2 $y2 L.lnofdiflow lns_f_num_ofdi_p2 cro2 $x1 $x2 $o1 $o2 $t1 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_ofdi_p2) iv(cro2 $x1 $x2 $o1 $o2 $t1 yeardum*) twostep
 est store s_inv 
 
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_proj2 cro3 $x1 $x2 $o1 $o2 $t1 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_proj2) iv(cro3 $x1 $x2 $o1 $o2 $t1 yeardum*) twostep
 est store s_aid
  
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_cont_p2 cro4 $x1 $x2 $o1 $o2 $t1 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_cont_p2) iv(cro4 $x1 $x2 $o1 $o2 $t1 yeardum*) twostep
 est store s_pro
 
 local s1 "L.lnofdiflow"
 local s2 "cro1 cro2 cro3 cro4"
 local s3 "lnt_s_num lns_f_num_ofdi_p2 lns_f_num_proj2 lns_f_num_cont_p2"
 local models "s_t s_inv s_aid s_pro"
 local order "`s1' `s2' `s3'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop cro* 
 
 *+++++++++++++++++++++++++++++++++++
 *    Panel B: Terrorist attack
 *+++++++++++++++++++++++++++++++++++  
 tsset nocoun year
 *-
 global t1 "lnter_event_a"
 
 gen cro1 = lnt_s_num         * $t1
 gen cro2 = lns_f_num_ofdi_p2 * $t1
 gen cro3 = lns_f_num_proj2   * $t1
 gen cro4 = lns_f_num_cont_p2 * $t1
 *-
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro1 $x1 $x2 $o1 $o2 $t1 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv(cro1 $x1 $x2 $o1 $o2 $t1 yeardum*) twostep
 est store s_t

 qui xtabond2 $y2 L.lnofdiflow lns_f_num_ofdi_p2 cro2 $x1 $x2 $o1 $o2 $t1 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_ofdi_p2) iv(cro2 $x1 $x2 $o1 $o2 $t1 yeardum*) twostep
 est store s_inv
 
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_proj2 cro3 $x1 $x2 $o1 $o2 $t1 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_proj2) iv(cro3 $x1 $x2 $o1 $o2 $t1 yeardum*) twostep
 est store s_aid
  
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_cont_p2 cro4 $x1 $x2 $o1 $o2 $t1 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_cont_p2) iv(cro4 $x1 $x2 $o1 $o2 $t1 yeardum*) twostep
 est store s_pro
 
 local s1 "L.lnofdiflow"
 local s2 "cro1 cro2 cro3 cro4"
 local s3 "lnt_s_num lns_f_num_ofdi_p2 lns_f_num_proj2 lns_f_num_cont_p2"
 local models "s_t s_inv s_aid s_pro"
 local order "`s1' `s2' `s3'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop cro*
 
 *+++++++++++++++++++++++++++++++
 *-    Heterogeneity analyis
 *+++++++++++++++++++++++++++++++

 *+++++++++++++++++++++++++++++++++++++++++++++++
 *- Table 11: OFDI entry mode:Greenfield vs CM&A
 *+++++++++++++++++++++++++++++++++++++++++++++++
 
 gen cro1 = lnt_s_num * r_green_pflow     
 gen cro2 = lnt_s_num * r_green_aflow  
 gen cro3 = lnt_s_num * r_green_pstock
 gen cro4 = lnt_s_num * r_green_astock 

 tsset nocoun year
 *-
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro1 r_green_pflow $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro1 r_green_pflow ) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m1
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro2 r_green_aflow $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro2 r_green_aflow) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m2
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro3 r_green_pstock $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro3 r_green_pstock) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m3
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro4 r_green_astock $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro4 r_green_astock) iv( $x1 $x2 $o1 $o2 yeardum*) twostep
 est store m4

 *-
 local s1 "L.lnofdiflow lnt_s_num"
 local s2 "cro1 cro2 cro3 cro4"
 local s3 "r_green_pflow r_green_aflow r_green_pstock r_green_astock"
 local models "m1 m2 m3 m4"
 local order "`s1' `s2' `s3'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop cro*
  
 *+++++++++++++++++++++++++++++++++++++++++++++++
 *-           Table 12: OFDI motivation
 *+++++++++++++++++++++++++++++++++++++++++++++++
 *-
 gen cro1 = lnt_s_num * r_num_OFDI_resource_nf
 gen cro2 = lnt_s_num * r_num_OFDI_market_nf  
 gen cro3 = lnt_s_num * r_num_OFDI_product_nf
 gen cro4 = lnt_s_num * r_num_OFDI_technology_nf
 gen cro5 = lnt_f_num * r_num_OFDI_other_nf
 
 tsset nocoun year
 *-
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro1 r_num_OFDI_resource_nf $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro1 r_num_OFDI_resource_nf) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m1
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro2 r_num_OFDI_market_nf  $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro2 r_num_OFDI_market_nf ) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m2
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro3 r_num_OFDI_product_nf $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro3 r_num_OFDI_product_nf ) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m3
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro4 r_num_OFDI_technology_nf $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro4 r_num_OFDI_technology_nf) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m4
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num  cro5 r_num_OFDI_other_nf $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro5 r_num_OFDI_other_nf) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m5
  
 local s1 "L.lnofdiflow lnt_s_num"
 local s2 "cro1 cro2 cro3 cro4 cro5"
 local s3 "r_num_OFDI_resource_nf r_num_OFDI_market_nf r_num_OFDI_product_nf r_num_OFDI_technology_nf r_num_OFDI_other_nf"
 local models "m1 m2 m3 m4 m5"
 local order "`s1' `s2' `s3'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f %10.0f %10.3f %10.3f %10.3f %10.3f %10.3f %10.3f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop cro*
 
 *+++++++++++++++++++++++++++++
 *- Table 13: Parent Sector
 *+++++++++++++++++++++++++++++ 
 *-
 gen cro1 = lnt_s_num * st_farm 
 gen cro2 = lnt_s_num * st_ind2nd 
 gen cro3 = lnt_s_num * st_mining 
 gen cro4 = lnt_s_num * st_manufacturing 
 gen cro5 = lnt_s_num * st_ind3nd1 
 gen cro6 = lnt_s_num * st_fin
 gen cro7 = lnt_s_num * st_ind3nd2

 tsset nocoun year
 
 *-
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro1 st_farm $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro1 st_farm) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m1
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro2 st_ind2nd $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro2 st_ind2nd) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m2
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro3 st_mining $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro3 st_mining) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m3
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro4 st_manufacturing $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro4 st_manufacturing) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m4
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro5 st_ind3nd1 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro5 st_ind3nd1) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m5
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro6 st_fin $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro6 st_fin) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m6
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro7 st_ind3nd2 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro7 st_ind3nd2) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m7  
 
 local s1 "L.lnofdiflow lnt_s_num"
 local s2 "cro1 cro2 cro3 cro4 cro5 cro6 cro7"
 local s3 "st_farm st_ind2nd st_mining st_manufacturing"
 local s4 "st_ind3nd1 st_fin st_ind3nd2"
 local models "m1 m2 m3 m4 m5 m6 m7"
 local order "`s1' `s2' `s3' `s4'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop cro*
 
 *++++++++++++++++++++++++++++++++++
 *-   Table 14: Country features
 *++++++++++++++++++++++++++++++++++
 
 cap gen developed = (economy == "1. Developed region: G7" | economy == "2. Developed region: nonG7")
 cap gen G7 = (economy == "1. Developed region: G7")
 cap gen BRIC = (economy == "3. Emerging region: BRIC")
 cap gen G20 = (economy == "5. Emerging region: G20")
 cap gen developing = (economy == "6. Developing region")
 cap gen ldeveloping = (economy == "7. Least developed region")
  
 gen cro1 = lnt_s_num * yes_obor    
 gen cro2 = lnt_s_num * yes_AIIB  
 gen cro3 = lnt_s_num * yes_neigh
 gen cro4 = lnt_s_num * yes_neighland 
 gen cro5 = lnt_s_num * yes_neighocean 

 tsset nocoun year
 
 *-----------------------------       
 *- Panel A: China framework
 *-----------------------------
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro1 yes_obor $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro1 yes_obor) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m11
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro2 yes_AIIB $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro2 yes_AIIB) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m12
 *----------------------------------       
 *- Panel B: Neighbouring countries
 *----------------------------------
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro3 yes_neigh $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro3 yes_neigh) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m21
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro4 yes_neighland $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro4 yes_neighland) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m22
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro5 yes_neighocean $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro5 yes_neighocean) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m23

 local s1 "L.lnofdiflow lnt_s_num"
 local s2 "cro1 cro2 cro3 cro4 cro5"
 local s3 "yes_obor yes_AIIB yes_neigh yes_neighland yes_neighocean"
 local s4 ""
 local models "m11 m12 m21 m22 m23"
 local order "`s1' `s2' `s3' `s4'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop cro*
 
 *---------------------------
 *- Panel C: Development
 *---------------------------
 gen cro1 = lnt_s_num * developed    
 gen cro2 = lnt_s_num * BRIC
 gen cro3 = lnt_s_num * G20
 gen cro4 = lnt_s_num * developing
 gen cro5 = lnt_s_num * ldeveloping

 tsset nocoun year
 *-
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro1 developed $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro1 developed) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store DCs
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro2 BRIC $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro2 BRIC) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store BRIC
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro3 G20 $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro3 G20) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store G20
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro4 developing $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro4 developing) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store LDCs
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro5 ldeveloping $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro5 ldeveloping) iv( $x1 $x2 $o1 $o2 yeardum*) twostep
 est store LLDCs
    
 local s1 "L.lnofdiflow lnt_s_num"
 local s2 "cro1 cro2 cro3 cro4 cro5"
 local s3 "developed BRIC G20 developing ldeveloping"
 local models "DCs BRIC G20 LDCs LLDCs"
 local order "`s1' `s2' `s3' `s4'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop cro*

 *++++++++++++++++++++++++++++++++++++
 *-   Table 15: Investment risk
 *++++++++++++++++++++++++++++++++++++

 *----------------------------- 
 *- Panel A: Fail rate - total
 *-----------------------------
 gen cro1 = lnt_s_num * L.r_fail_pflow     
 gen cro2 = lnt_s_num * L.r_fail_aflow  
 
 tsset nocoun year
 
 *-
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro1 L.r_fail_pflow $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro1 L.r_fail_pflow) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m1
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro2 L.r_fail_aflow $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro2 L.r_fail_aflow) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m2

 local s1 "L.lnofdiflow lnt_s_num"
 local s2 "cro1 cro2"
 local s3 "L.r_fail_pflow L.r_fail_aflow"
 local models "m1 m2"
 local order "`s1' `s2' `s3'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop cro*
 
 *---------------------------------- 
 *- Panel B: Fail rate - Greenfield
 *----------------------------------
 gen cro1 = lnt_s_num * L.r_fail_g_pflow     
 gen cro2 = lnt_s_num * L.r_fail_g_aflow  

 tsset nocoun year

 *-
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro1 L.r_fail_g_pflow $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro1 L.r_fail_g_pflow) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m1
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro2 L.r_fail_g_aflow $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro2 L.r_fail_g_aflow) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m2
 
 local s1 "L.lnofdiflow lnt_s_num"
 local s2 "cro1 cro2"
 local s3 "L.r_fail_g_pflow L.r_fail_g_aflow"
 local models "m1 m2"
 local order "`s1' `s2' `s3'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop cro*
 
 *---------------------------------- 
 *- Panel C: Fail rate - CM&A
 *----------------------------------
 tsset nocoun year
 
 gen cro1 = lnt_s_num * L.r_fail_m_pflow     
 gen cro2 = lnt_s_num * L.r_fail_m_aflow  

 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro1 L.r_fail_m_pflow $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro1 L.r_fail_m_pflow) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m1
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num cro2 L.r_fail_m_aflow $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num cro2 L.r_fail_m_aflow) iv($x1 $x2 $o1 $o2 yeardum*) twostep
 est store m2
 
 local s1 "L.lnofdiflow lnt_s_num"
 local s2 "cro1 cro2"
 local s3 "L.r_fail_m_pflow L.r_fail_m_aflow"
 local models "m1 m2"
 local order "`s1' `s2' `s3'"
 local dropvars "yeardum*"

 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop cro*

 *++++++++++++++++++++++++++++++++
 *-     Table 16: Time Dynamic
 *++++++++++++++++++++++++++++++++
 *--------------------------------------------------------------
 *- Panel A:Two period 2005-2014 (2005-2009; 2010-2014) - stock  
 *--------------------------------------------------------------
 
 gen cro1014A = lnt_s_num if year == 2010 | year == 2011 | year == 2012 | year == 2013 | year ==  2014
 replace cro1014A = 0 if cro1014A == .
 
 gen cro1014B = lns_f_num_ofdi_p2 if year == 2010 | year == 2011 | year == 2012 | year == 2013 | year ==  2014
 replace cro1014B = 0 if cro1014B == . 
 
 gen cro1014C = lns_f_num_proj2 if year == 2010 | year == 2011 | year == 2012 | year == 2013 | year ==  2014
 replace cro1014C = 0 if cro1014C == . 
 
 gen cro1014D = lns_f_num_cont_p2 if year == 2010 | year == 2011 | year == 2012 | year == 2013 | year ==  2014
 replace cro1014D = 0 if cro1014D == . 
 
 global mmA "cro1014A"
 global mmB "cro1014B"
 global mmC "cro1014C" 
 global mmD "cro1014D" 
  
 *-
 tsset nocoun year
 
 qui xtabond2 $y2 L.lnofdiflow lnt_s_num $mmA $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_s_num) iv($mmA $x1 $x2 $o1 $o2 yeardum*) twostep
 est store all
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_ofdi_p2 $mmB $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_ofdi_p2) iv($mmB $x1 $x2 $o1 $o2 yeardum*) twostep
 est store inv
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_proj2 $mmC $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_proj2) iv($mmC $x1 $x2 $o1 $o2 yeardum*) twostep
 est store aid
 qui xtabond2 $y2 L.lnofdiflow lns_f_num_cont_p2 $mmD $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lns_f_num_cont_p2) iv($mmD $x1 $x2 $o1 $o2 yeardum*) twostep
 est store pro
 
 local s1 "L.lnofdiflow lnt_s_num lns_f_num_ofdi_p2 lns_f_num_proj2 lns_f_num_cont_p2"
 local s2 "$mmA $mmB $mmC $mmD"

 local models "all inv aid pro"
 local order "`s1' `s2'"
 local dropvars "yeardum*"
 
 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop cro*
 
 *--------------------------------------------------------------
 *- Panel B:Two period 2005-2014 (2005-2009; 2010-2014)  - flow
 *--------------------------------------------------------------
 
 gen cro1014A = lnt_f_num if year == 2010 | year == 2011 | year == 2012 | year == 2013 | year ==  2014
 replace cro1014A = 0 if cro1014A == .
 
 gen cro1014B = lnf_num_ofdi_p2 if year == 2010 | year == 2011 | year == 2012 | year == 2013 | year ==  2014
 replace cro1014B = 0 if cro1014B == . 
 
 gen cro1014C = lnf_num_proj2 if year == 2010 | year == 2011 | year == 2012 | year == 2013 | year ==  2014
 replace cro1014C = 0 if cro1014C == . 
 
 gen cro1014D = lnf_num_cont_p2 if year == 2010 | year == 2011 | year == 2012 | year == 2013 | year ==  2014
 replace cro1014D = 0 if cro1014D == . 
    
 *- 
 global mmA "cro1014A"
 global mmB "cro1014B"
 global mmC "cro1014C" 
 global mmD "cro1014D" 
  
 *-
 tsset nocoun year
 
 qui xtabond2 $y2 L.lnofdiflow lnt_f_num $mmA $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnt_f_num) iv($mmA $x1 $x2 $o1 $o2 yeardum*) twostep
 est store all
 qui xtabond2 $y2 L.lnofdiflow lnf_num_ofdi_p2 $mmB $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnf_num_ofdi_p2) iv($mmB $x1 $x2 $o1 $o2 yeardum*) twostep
 est store inv
 qui xtabond2 $y2 L.lnofdiflow lnf_num_proj2 $mmC $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnf_num_proj2) iv($mmC $x1 $x2 $o1 $o2 yeardum*) twostep
 est store aid
 qui xtabond2 $y2 L.lnofdiflow lnf_num_cont_p2 $mmD $x1 $x2 $o1 $o2 yeardum* $c0, ///
 gmm(L.lnofdiflow lnf_num_cont_p2) iv($mmD $x1 $x2 $o1 $o2 yeardum*) twostep
 est store pro
 
 local s1 "L.lnofdiflow lnt_f_num lnf_num_ofdi_p2 lnf_num_proj2 lnf_num_cont_p2"
 local s2 "$mmA $mmB $mmC $mmD"
 local models "all inv aid pro"
 local order "`s1' `s2'"
 local dropvars "yeardum*"
 
 esttab `models', b(%6.3f) se(%6.3f) mtitle(`models') sca(N N_g) ///
 sfmt(%10.0f %10.0f) ///
 star(* 0.1 ** 0.05 *** 0.01) order(`order') drop(`dropvars') nogaps compress 
 
 drop cro*
 
 *=================
 *- The end
 *=================
